<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="248"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd، d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>إعدادات الساعة العالمية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>ت&amp;نسيق العرض</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>الو&amp;قت</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>الت&amp;نسيق:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>قصير</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>طويل</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation>مخصّص</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>ا&amp;عرض الثواني</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>أ&amp;سبِق عدد الساعات بصفر</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>المن&amp;طقة الزمنية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>الم&amp;كان:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>الت&amp;نسيق:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>بالأسفل</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>بالأعلى</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>قبل</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>بعد</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>الإزاحة من التوقيت العالمي المنسّق</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>الاختصار</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>معرّف IANA</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="591"/>
        <source>Custom name</source>
        <translation>الاسم المخصّص</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>ا&amp;ستخدم وضع ١٢ ساعة</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>معرّف المكان</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>ال&amp;تاريخ</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>الم&amp;كان:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>الت&amp;نسيق:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>آيزو ٨٦٠١</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>اعرض ال&amp;سنة</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>اعرض يوم الأ&amp;سبوع</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>أ&amp;سبِق اليوم بصفر</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>أسماء الأشهر وأيام الأسبوع &amp;طويلة</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>تنسيق يدوي مت&amp;قدّم</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customize ...</source>
        <translation>&amp;خصّص…</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>المنا&amp;طق الزمنية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>أ&amp;ضِف…</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>أ&amp;زِل</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>اضبط &amp;كمبدئي</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>&amp;حرّر الاسم المخصّص…</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation>انقل لأ&amp;على</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation>انقل لأ&amp;سفل</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="518"/>
        <source>Change displayed time zone with mouse wheel</source>
        <translation>تغيير المنطقة الزمنية المعروضة باستخدام عجلة الماوس</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="525"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Middle-click the clock to view the time and date for all configured timezones.</source>
        <translation>&lt;b&gt;ملاحظة:&lt;/b&gt; انقر بزر الماوس الأوسط فوق الساعة لعرض الوقت والتاريخ لجميع المناطق الزمنية التي تم تكوينها.</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="536"/>
        <source>&amp;General</source>
        <translation>&amp;عام</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="542"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;دوّر آليا عندما تكون اللوحة رأسية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="552"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>إظهار أرقام الأسبوع في التقويم المنبثق</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="562"/>
        <source>S&amp;how tooltip</source>
        <translation>إظهار تلميح الأداة</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="108"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd، d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="590"/>
        <source>Input custom time zone name</source>
        <translation>أدخِل اسم المنطقة الزمنية المخصّص</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>إعداد تنسيق يدوي للساعة العالمية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt; بنية تنسيق التاريخ / الوقت المخصص &lt;/ h1&gt;
&lt;p&gt; نمط التاريخ هو سلسلة من الأحرف ، حيث يتم استبدال سلاسل محددة من الأحرف ببيانات التاريخ والوقت من التقويم عند التنسيق أو استخدامها لإنشاء بيانات لتقويم عند التحليل. &lt;/p&gt;
&lt;p&gt; يحتوي جدول رموز حقل التاريخ أدناه على الأحرف المستخدمة في الأنماط لإظهار التنسيقات المناسبة للإعداد المحلي المحدد ، مثل yyyy للسنة. يمكن استخدام الأحرف عدة مرات. على سبيل المثال ، إذا تم استخدام y للسنة ، فقد ينتج &quot;yy&quot; &quot;99&quot; ، بينما ينتج &quot;yyyy&quot; &quot;1999&quot;. بالنسبة لمعظم الحقول الرقمية ، يحدد عدد الأحرف عرض الحقل. على سبيل المثال ، إذا كانت h هي الساعة ، فقد ينتج عن &quot;h&quot; &quot;5&quot; ، ولكن &quot;hh&quot; ينتج &quot;05&quot;. بالنسبة لبعض الأحرف ، يحدد العدد ما إذا كان يجب استخدام صيغة مختصرة أو كاملة ، ولكن قد يكون لها خيارات أخرى ، كما هو موضح أدناه. &lt;/p&gt;
&lt;p&gt; علامتا اقتباس مفردتان تمثلان اقتباسًا منفردًا حرفيًا ، إما داخل علامتي اقتباس مفردة أو خارجها. لا يتم تفسير النص داخل علامات الاقتباس المفردة بأي شكل من الأشكال (باستثناء علامتي اقتباس متجاورتين). وبخلاف ذلك ، يتم حجز جميع أحرف ASCII من a إلى z ومن A إلى Z كأحرف بناء ، وتتطلب اقتباسًا إذا كانت تمثل أحرفًا حرفية. بالإضافة إلى ذلك ، قد تتغير بعض أحرف علامات الترقيم ASCII في المستقبل (على سبيل المثال ، &quot;:&quot; يتم تفسيرها على أنها فاصل زمني و &quot;/&quot; كفاصل تاريخ ، واستبدالها بأحرف حساسة للغة في العرض). &lt;br /&gt; &lt; / ص&gt;
&lt;table border = &quot;1&quot; width = &quot;100%&quot; cellpadding = &quot;4&quot; cellspacing = &quot;0&quot;&gt;
&lt;tr&gt; &lt;th width = &quot;20%&quot;&gt; Code &lt;/th&gt; &lt;th&gt; المعنى &lt;/th&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; d &lt;/td&gt; &lt;td&gt; اليوم كرقم بدون صفر بادئ (من 1 إلى 31) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; dd &lt;/td&gt; &lt;td&gt; اليوم كرقم بصفر بادئ (من 01 إلى 31) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; ddd &lt;/td&gt; &lt;td&gt; اسم اليوم المترجم المختصر (مثل &quot;Mon&quot; إلى &quot;Sun&quot;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; dddd &lt;/td&gt; &lt;td&gt; اسم اليوم المترجم الطويل (مثل &quot;من الاثنين&quot; إلى &quot;الأحد&quot;). &lt;/ td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; M &lt;/td&gt; &lt;td&gt; الشهر كرقم بدون صفر بادئ (1-12) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; MM &lt;/td&gt; &lt;td&gt; الشهر كرقم بصفر بادئ (01-12) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; MMM &lt;/td&gt; &lt;td&gt; اسم الشهر المترجم المختصر (مثل &quot;يناير&quot; إلى &quot;ديسمبر&quot;). &lt;/ td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; MMMM &lt;/td&gt; &lt;td&gt; اسم الشهر المترجم الطويل (على سبيل المثال ، من &quot;يناير&quot; إلى &quot;ديسمبر&quot;). &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; yy &lt;/td&gt; &lt;td&gt; العام كرقم مكون من رقمين (00-99) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; yyyy &lt;/td&gt; &lt;td&gt; السنة كرقم مكون من أربعة أرقام &lt;/ td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; h &lt;/td&gt; &lt;td&gt; الساعة بدون صفر بادئ (من 0 إلى 23 أو من 1 إلى 12 في حالة عرض AM /pM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; hh &lt;/td&gt; &lt;td&gt; الساعة بصفر بادئ (من 00 إلى 23 أو من 01 إلى 12 في حالة عرض AM /pM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; H &lt;/td&gt; &lt;td&gt; الساعة بدون صفر بادئ (من 0 إلى 23 ، حتى مع عرض AM /pM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; HH &lt;/td&gt; &lt;td&gt; الساعة بصفر بادئ (من 00 إلى 23 ، حتى مع عرض AM /pM) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; m &lt;/td&gt; &lt;td&gt; الدقيقة بدون صفر بادئ (0 إلى 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; mm &lt;/td&gt; &lt;td&gt; الدقيقة بصفر بادئ (من 00 إلى 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; s &lt;/td&gt; &lt;td&gt; الثانية بدون صفر بادئ (0 إلى 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; ss &lt;/td&gt; &lt;td&gt; الثانية بصفر بادئ (من 00 إلى 59) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; AP &lt;i&gt; أو &lt;/i&gt; A &lt;/td&gt; &lt;td&gt; استخدم عرض AM /pM. سيتم استبدال &lt;b&gt; A / AP &lt;/b&gt; إما بـ &quot;AM&quot; أو &quot;PM&quot;. &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; ap &lt;i&gt; أو &lt;/i&gt; a &lt;/td&gt; &lt;td&gt; استخدم عرض am /pm. سيتم استبدال &lt;b&gt; a / ap &lt;/b&gt; إما بـ &quot;am&quot; أو &quot;pm&quot;. &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; t &lt;/td&gt; &lt;td&gt; المنطقة الزمنية (مثل &quot;CEST&quot;) &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; T &lt;/td&gt; &lt;td&gt; الإزاحة من التوقيت العالمي المنسق &lt;/ td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; TT &lt;/td&gt; &lt;td&gt; معرّف IANA للمنطقة الزمنية &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; TTT &lt;/td&gt; &lt;td&gt; اختصار المنطقة الزمنية &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; TTTT &lt;/td&gt; &lt;td&gt; اسم العرض القصير للمنطقة الزمنية &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; TTTTT &lt;/td&gt; &lt;td&gt; اسم العرض الطويل للمنطقة الزمنية &lt;/ td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; TTTTTT &lt;/td&gt; &lt;td&gt; الاسم المخصص للمنطقة الزمنية. يمكنك تغيير علامة التبويب &quot;المناطق الزمنية&quot; في نافذة التكوين &lt;/td&gt; &lt;/tr&gt; &lt;/table&gt;
&lt;br /&gt; &lt;b&gt; ملاحظات: &lt;/b&gt; &lt;ul&gt; &lt;li&gt; أية أحرف في النمط ليست في نطاقات [&apos;a&apos; .. &apos;z&apos;] و [&apos;A&apos; .. &apos;Z سيتم التعامل مع &apos;] كنص مقتبس. على سبيل المثال ، ستظهر أحرف مثل &quot;:&quot; و &quot;.&quot; و &quot;&quot; و &quot;#&quot; و &quot;@&quot; في نص الوقت الناتج حتى لم يتم تضمينها داخل علامات اقتباس مفردة. يستخدم الاقتباس المنفرد في &quot;الهروب&quot; من الأحرف. علامتا اقتباس منفردتان متتاليتان ، سواء داخل تسلسل مقتبس أو خارجه ، يمثلان اقتباسًا منفردًا &quot;حقيقيًا&quot;. &lt;/ li&gt; &lt;li&gt; أقل فترة تحديث هي ثانية واحدة. إذا تم تكوين z أو zzz ، فسيتم عرض الوقت مع جزء الملي ثانية ، ولكن لا يتم تحديثه على أساس مللي ثانية (تجنب حدوث نجاح كبير في الأداء). &lt;/ li&gt; &lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>المناطق الزمنية للساعة العالمية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>المنطقة الزمنية</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>تعليق</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>الدولة</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>التوقيت العالمي المنسّق</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>أخرى</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>المنطقة الزمنية المحلية</translation>
    </message>
</context>
</TS>
